# More Notes

## Links From the Scaffolded Setttings File
Generated by `django-admin startproject`
- https://docs.djangoproject.com/en/dev/topics/settings/
- https://docs.djangoproject.com/en/dev/ref/settings/
- https://docs.djangoproject.com/en/dev/howto/deployment/checklist/
- https://docs.djangoproject.com/en/dev/ref/settings/#auth-password-validators
- https://docs.djangoproject.com/en/dev/topics/i18n/
- https://docs.djangoproject.com/en/dev/howto/static-files/
- https://docs.djangoproject.com/en/dev/ref/settings/#databases
- https://docs.djangoproject.com/en/dev/ref/settings/#default-auto-field

## More Django Docs
- https://docs.djangoproject.com/en/dev/topics/auth/customizing/#substituting-a-custom-user-model
- https://docs.djangoproject.com/en/dev/ref/contrib/sites/

## Extra Dependency References
- https://github.com/cobrateam/django-htmlmin
- https://github.com/feincms/django-tree-queries
- https://github.com/ivelum/djangoql

## Optional Dependency References
- https://pypi.org/project/django-timezone-field/
- https://django-compressor.readthedocs.io/en/stable/
- https://github.com/meeb/django-cachekiller
- https://github.com/meeb/django-distill